#
# spec file for package lucene++
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lucene++
Version:        3.0.9
Release:        1.1
Summary:        A high-performance, full-featured text search engine written in C++
License:        Apache-2.0 OR LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/luceneplusplus/LucenePlusPlus
Source:         https://github.com/luceneplusplus/LucenePlusPlus/archive/rel_%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM lucene++-3.0.9-fix-cmake-issues.patch -- https://github.com/luceneplusplus/LucenePlusPlus/pull/203
Patch4:         lucene++-3.0.9-fix-boost1.85.patch
# PATCH-FIX-UPSTREAM lucene++-3.0.9-migrate-to-boost-asio-io_context.patch -- https://github.com/luceneplusplus/LucenePlusPlus/pull/210
Patch5:         lucene++-3.0.9-migrate-to-boost-asio-io_context.patch
# PATCH-FIX-UPSTREAM https://github.com/luceneplusplus/LucenePlusPlus/pull/200
Patch6:         lucene++-3.0.9-fix-linking-DefaultSimilarity.patch
BuildRequires:  cmake >= 3.5
BuildRequires:  gcc-c++
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(zlib)

%description
An up to date C++ port of the popular Java Lucene library, a high-performance, full-featured text search engine.

%package -n liblucene++0
Summary:        A high-performance, full-featured text search engine written in C++
Group:          Development/Libraries/C and C++

%description -n liblucene++0
An up to date C++ port of the popular Java Lucene library, a high-performance, full-featured text search engine.

%package devel
Summary:        Development files for lucene++
Group:          Development/Libraries/C and C++
Requires:       liblucene++0 = %{version}

%description devel
Development files for lucene++, a high-performance, full-featured text search engine written in C++

%prep
%autosetup -p1 -n LucenePlusPlus-rel_%{version}

%build
%cmake -DINSTALL_GTEST=OFF
%make_build lucene++ lucene++-contrib

%install
%cmake_install

%check
# Disable test failing with "config out of range"
export skip_tests_filter=-$(echo \
    SortTest.testEmptyFieldSort \
    SortTest.testParallelMultiSort \
    ParallelMultiSearcherTest.testEmptyIndex \
    ParallelMultiSearcherTest.testFieldSelector \
    ParallelMultiSearcherTest.testNormalization \
    ParallelMultiSearcherTest.testCustomSimilarity \
    ParallelMultiSearcherTest.testDocFreq \
%ifarch %{ix86} # Exclude known failing test on ix86 (https://github.com/luceneplusplus/LucenePlusPlus/issues/98)
    Boolean2Test.testRandomQueries \
%endif
    %{nil} | tr ' ' ':')
# Tweak path to allow lucene++-tester to find liblucene++ and libgtest
export LD_LIBRARY_PATH="$PWD/build/src/core:$PWD/build/src/contrib:$PWD/build/lib"
build/src/test/lucene++-tester --gtest_filter="${skip_tests_filter}"

%ldconfig_scriptlets -n liblucene++0

%files -n liblucene++0
%{_libdir}/liblucene++.so.*
%{_libdir}/liblucene++-contrib.so.*
%license COPYING APACHE.license GPL.license LGPL.license
%doc AUTHORS README* REQUESTS

%files devel
%license COPYING APACHE.license GPL.license LGPL.license
%{_includedir}/lucene++/
%{_libdir}/cmake/liblucene++/
%{_libdir}/cmake/liblucene++-contrib/
%{_libdir}/liblucene++.so
%{_libdir}/liblucene++-contrib.so
%{_libdir}/pkgconfig/liblucene++.pc
%{_libdir}/pkgconfig/liblucene++-contrib.pc

%changelog
* Tue Apr  8 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.0.9:
  * fix race conditions whe initializing static variables
  * build system fixes
- add patch lucene++-3.0.9-fix-linking-DefaultSimilarity.patch
- Drop patches merged upstream:
  * lucene++-3.0.8-fix-contrib-soname.patch
  * lucene++-3.0.8-fix-pc-libdir.patch
  * lucene++-3.0.8-fix-missing-headers.patch
  * lucene++-3.0.8-fix-cmake-issues.patch
* Tue Mar 18 2025 Markéta Machová <mmachova@suse.com>
- Add lucene++-3.0.9-migrate-to-boost-asio-io_context.patch
  * fix with boost 1.87
* Fri Apr 26 2024 Ana Guerrero <ana.guerrero@suse.com>
- Fix build with boost 1.85, add patch lucene++-3.0.9-fix-boost1.85.patch
* Wed Apr 12 2023 Antoine Belvire <antoine.belvire@opensuse.org>
- Add explicit build dependency on libboost_atomic-devel: Fix build
  with older boost version (Leap 15.5).
* Tue Jun  8 2021 Hillwood Yang <hillwood@opensuse.org>
- Contrib headers should be installed, add lucene++-3.0.8-fix-missing-headers.patch
* Thu Jan 21 2021 antoine.belvire@opensuse.org
- Add CMake option to prevent installation of gtest files instead
  of removing them by hand.
- Remove obsolete build dependency on subversion.
* Sat Jan 16 2021 antoine.belvire@opensuse.org
- Update to version 3.0.8:
  * No changelog provided.
- Remove 0001-Fix-compilation-with-Boost-1.58.patch: Merged
  upstream.
- Add some patches from upstream, mainly build system fixes:
  * lucene++-3.0.8-fix-contrib-soname.patch
  * lucene++-3.0.8-fix-pc-libdir.patch
  * lucene++-3.0.8-fix-cmake-issues.patch
- Require CMake >= 3.5 to build.
- Run test suite on build.
- Add new cmake files to list of installed files.
* Sat Dec 26 2020 antoine.belvire@opensuse.org
- Add some build dependencies (used to be implicitly pulled):
  * pkgconfig(bzip2)
  * pkgconfig(zlib)
- Remove obsolete conditionals.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue May 19 2015 astieger@suse.com
- fix build with boost 1.58, adding upstream patch
  0001-Fix-compilation-with-Boost-1.58.patch
* Fri Feb 27 2015 astieger@suse.com
- lucene++ 3.0.7:
  * no upstream changelog
  * remove patches now upstream:
    lucene++-3.0.6-fix_installing_headers.patch
    lucene++-3.0.6-multiarch.patch
    lucene++-3.0.6-pc_files_fix.patch
* Sun Oct 19 2014 andreas.stieger@gmx.de
- fixes for .pc files in lucene++-3.0.6-pc_files_fix.patch
- add upstream patch lucene++-3.0.6-multiarch.patch to work with
  %%cmake makro
- fix build for openSUSE 12.3
* Sat Oct 18 2014 andreas.stieger@gmx.de
- lucene++ 3.0.6, a high-performance, full-featured text search
  engine written in C++,
- upstream patches:
  * lucene++-3.0.6-pc_files_fix.patch - fix pkgconfig files
  * lucene++-3.0.6-fix_installing_headers.patch fix header install
